<?php
// $Id: nrembrowser.admin.inc,v 1.1.2.3 2010/07/01 21:40:02 aaron Exp $

/**
 * @file
 * Administrative pages for Node Reference/Embed Media Browser (nrembrowser).
 */

/**
 * Page callback for admin/settings/nrembrowser.
 */
function nrembrowser_settings() {
  $form = array();

  $form['types'] = array(
    '#type' => 'fieldset',
    '#title' => t('Node type settings'),
    // Add vertical tabs display if available.
    '#pre_render' => array('vertical_tabs_form_pre_render'),
    '#attributes' => array(
      'id' => 'nrembrowser-types',
    ),
    '#collapsible' => TRUE,
  );

  $types = content_types();

  foreach (node_get_types('names') as $type => $name) {
    $form['types'][$type] = array(
      '#type' => 'fieldset',
      '#title' => check_plain($name),
      '#prefix' => '<div id="nrembrowser-type-'. $type .'" class="nrembrowser-type"></div>',
      // This is D7-style attached properties that will only work if vertical tabs is installed.
      '#attached' => array(
        'js' => array(
          'vertical-tabs' => drupal_get_path('module', 'nrembrowser') . '/includes/nrembrowser.vertical_tabs.js',
        ),
      ),
    );

    $form['types'][$type][nrembrowser_variable_name('wysiwyg_type_allowed_'. $type)] = array(
      '#type' => 'checkbox',
      '#title' => t('Allowed in WYSIWYG'),
      '#description' => t('When checking this box, if you have !WYSIWYG installed, you may then reference and display content of the %type type inline.', array('%type' => $name, '!WYSIWYG' => l(t('WYSIWYG'), 'http://drupal.org/project/wysiwyg', array('attributes' => array('target' => '_blank'))))),
      '#default_value' => nrembrowser_variable_get('wysiwyg_type_allowed_'. $type),
    );

    $options = array(
      'teaser' => t('Node teaser'),
      'full' => t('Full node'),
    );

    foreach ($types[$type]['fields'] as $field) {
      if (in_array($field['type'], array('text', 'filefield', 'link', 'emvideo', 'emimage', 'emaudio'))) {
        $options[$field['field_name']] = t('@label (%type)', array('@label' => $field['widget']['label'], '%type' => $field['type'] .' field'));
      }
    }

    $form['types'][$type][nrembrowser_variable_name('browser_image_'. $type)] = array(
      '#type' => 'radios',
      '#title' => t('Select browser thumbnail from'),
      '#description' => t('This selection will determine from where to select the dialog browser thumbnail from the content of the %type type.', array('%type' => $name)),
      '#options' => $options,
      '#default_value' => nrembrowser_variable_get('browser_image_'. $type),
      '#attributes' => array(
        'class' => 'nrembrowser-browser-image',
      ),
    );
  }

  drupal_add_js(array('nrembrowser' => array('types' => node_get_types('names'))), 'setting');

  return system_settings_form($form);
}
